fn apply_state_changeset<N: Network, B: ForkBlockEnv>(
state: EvmState,
journaled_state: &mut JournaledState,
fork: &mut Fork<N, B>,
persistent_accounts: &HashSet<Address>,
) -> Result<(), BackendError>Expand description
Applies the changeset of a transaction to the active journaled state and also commits it in the forked db