fn commit_transaction<FEN: FoundryEvmNetwork>(
transaction: TransactionInputs<FEN>,
journaled_state: &mut JournaledState,
fork: &mut Fork<AnyNetwork, BlockEnvFor<FEN>>,
fork_id: &ForkId,
networks: NetworkConfigs,
persistent_accounts: &HashSet<Address>,
inspector: &mut dyn for<'db> FoundryInspectorExt<<FEN::EvmFactory as FoundryEvmFactory>::FoundryContext<'db>>,
) -> Result<()>Expand description
Executes the given transaction and commits state changes to the database and the journaled state, with an inspector.