commit_transaction

Function commit_transaction 

fn commit_transaction<FEN: FoundryEvmNetwork>(
    evm_env: EvmEnvFor<FEN>,
    tx_env: TxEnvFor<FEN>,
    journaled_state: &mut JournaledState,
    fork: &mut Fork<AnyNetwork, BlockEnvFor<FEN>>,
    fork_id: &ForkId,
    persistent_accounts: &HashSet<Address>,
    inspector: &mut dyn for<'db> FoundryInspectorExt<<FEN::EvmFactory as FoundryEvmFactory>::FoundryContext<'db>>,
) -> Result<()>
Executes the given transaction and commits state changes to the database and the journaled state, with an inspector.