fn commit_transaction(
tx: &AnyRpcTransaction,
evm_env: &mut EvmEnv,
tx_env: &mut TxEnv,
journaled_state: &mut JournaledState,
fork: &mut Fork,
fork_id: &ForkId,
persistent_accounts: &HashSet<Address>,
inspector: &mut dyn EthInspectorExt,
) -> Result<()>Expand description
Executes the given transaction and commits state changes to the database and the journaled state, with an inspector.